@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,7 +35,7 @@ public:
     ~SendLaterTimeDateWidget();
 
     void setDateTime(const QDateTime &);
-    QDateTime dateTime() const;
+    Q_REQUIRED_RESULT QDateTime dateTime() const;
 
 Q_SIGNALS:
     void dateTimeChanged(const QDateTime &);
